galaxy_get_workflow_inputs: Retrieve input definitions for a Galaxy workflow

galaxy_get_workflow_inputsR Documentation

Retrieve input definitions for a Galaxy workflow

Description

Retrieves and summarizes the input steps required by a Galaxy workflow.

Usage

galaxy_get_workflow_inputs(workflow_id, galaxy_url = "https://usegalaxy.eu")

Arguments

workflow_id

Character. Galaxy workflow ID.

galaxy_url

Character. Base URL of the Galaxy instance (for example "https://usegalaxy.eu"). If the environment variable GALAXY_URL is set, it takes precedence.

Details

This function queries /api/workflows/{workflow_id} and extracts workflow input steps (data and parameter inputs). The returned step_id values must be used as names in the inputs argument of galaxy_start_workflow.

Value

A data.frame with one row per workflow input and the columns: step_id, name, type, optional, default.

Examples


## Not run: 
galaxy_get_workflow_inputs("f2db41e1fa331b3e")

## End(Not run)


GalaxyR documentation built on July 6, 2026, 5:08 p.m.