galaxy_poll_tool: Generic for galaxy_poll_tool

galaxy_poll_toolR Documentation

Generic for galaxy_poll_tool

Description

Generic for galaxy_poll_tool

Wait for a Galaxy job to complete

S4 method to poll the status of a tool invocation

Usage

galaxy_poll_tool(
  x,
  galaxy_url = "https://usegalaxy.eu",
  poll_interval = 3,
  timeout = 600
)

## S4 method for signature 'character'
galaxy_poll_tool(
  x,
  galaxy_url = "https://usegalaxy.eu",
  poll_interval = 3,
  timeout = 600
)

## S4 method for signature 'Galaxy'
galaxy_poll_tool(x, poll_interval = 3, timeout = 600)

Arguments

x

A job ID (character) or a Galaxy object.

galaxy_url

Base URL of the Galaxy instance, used by the character method.

poll_interval

Seconds between status checks.

timeout

Maximum time to wait in seconds.

Value

For the character method, the final job object; for the Galaxy method, the modified Galaxy object.


GalaxyR documentation built on July 6, 2026, 5:08 p.m.