View source: R/2025-10-27_JF_R_Galaxy_functions.R
| galaxy_set_credentials | R Documentation |
Set Galaxy connection parameters for the current R session
galaxy_set_credentials(
api_key = NULL,
username = NULL,
password = NULL,
galaxy_url = "https://usegalaxy.eu",
overwrite = TRUE
)
api_key |
Character. Galaxy API key. |
username |
Character. Galaxy username (only required for FTP uploads). |
password |
Character. Galaxy password (only required for FTP uploads). |
galaxy_url |
Character. Base URL of the Galaxy instance
(e.g. |
overwrite |
Logical. Whether to overwrite existing environment
variables. Default: |
This helper is intended for interactive sessions. It sets the following
environment variables using Sys.setenv():
GALAXY_API_KEY
GALAXY_URL
GALAXY_USERNAME
GALAXY_PASSWORD
Only arguments that are provided (non-NULL) are set.
Invisibly returns a named list of values that were set.
# This requires valid credentials to your galaxy instance
## Not run:
galaxy_set_credentials(
api_key = "your-secret-key",
username = "your-username",
password = "your-password",
galaxy_url = "https://usegalaxy.eu"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.