| galaxy_download_rocrate | R Documentation |
galaxy_download_rocrate() is an S4 generic. With x as a history ID
(character) it requests an export in RO-Crate format, polls until ready,
and downloads the archive to dest_file. With x as a Galaxy object,
its history_id and galaxy_url are used and the object is returned
invisibly after performing the download.
galaxy_download_rocrate(
x,
dest_file = tempfile(fileext = ".zip"),
galaxy_url = "https://usegalaxy.eu",
format = "rocrate.zip",
poll_interval = 5,
timeout = 600
)
## S4 method for signature 'character'
galaxy_download_rocrate(
x,
dest_file = tempfile(fileext = ".zip"),
galaxy_url = "https://usegalaxy.eu",
format = "rocrate.zip",
poll_interval = 30,
timeout = 600
)
## S4 method for signature 'Galaxy'
galaxy_download_rocrate(
x,
dest_file = tempfile(fileext = ".zip"),
format = format,
poll_interval = 5,
timeout = 600
)
x |
A history ID ( |
dest_file |
Path to save the downloaded RO-Crate (defaults to a
temporary |
galaxy_url |
Base URL of the Galaxy instance, used by the character
method. If |
format |
Format for the history export. Possible formats depend on the Galaxy server. Typical inputs are 'tgz', 'tar', 'tar.gz', 'bag.zip', 'bag.tar', 'bag.tgz', 'rocrate.zip' or 'bco.json'. Defaults to 'rocrate.zip'. |
poll_interval |
Seconds between status checks. |
timeout |
Maximum time to wait in seconds before giving up. |
For the character method, the path to the downloaded file. For the
Galaxy method, the (unchanged) Galaxy object invisibly.
hid <- "0123456789abcdef"
crate <- galaxy_download_rocrate(hid, dest_file = "history_rocrate.zip")
g <- galaxy()
g <- galaxy_initialize(g)
g <- galaxy_download_rocrate(g, dest_file = "history_rocrate.zip")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.