| galaxy_get_workflow_inputs | R Documentation |
Retrieves and summarizes the input steps required by a Galaxy workflow.
galaxy_get_workflow_inputs(workflow_id, galaxy_url = "https://usegalaxy.eu")
workflow_id |
Character. Galaxy workflow ID. |
galaxy_url |
Character. Base URL of the Galaxy instance
(for example |
This function queries /api/workflows/{workflow_id} and extracts
workflow input steps (data and parameter inputs). The returned
step_id values must be used as names in the inputs argument
of galaxy_start_workflow.
A data.frame with one row per workflow input and the columns:
step_id, name, type, optional, default.
## Not run:
galaxy_get_workflow_inputs("f2db41e1fa331b3e")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.