View source: R/2025-10-27_JF_R_Galaxy_functions.R
| galaxy_history_size | R Documentation |
The function first tries to read a size/disk_usage field from the history summary endpoint. If that is not present it fetches the history contents and sums dataset sizes (robust to a few different field names used by different Galaxy versions). Results are returned as a data.frame with bytes and a human-readable size.
galaxy_history_size(
history_id,
galaxy_url = "https://usegalaxy.eu",
include_deleted = FALSE
)
history_id |
Galaxy history ID. |
galaxy_url |
Character. Base URL of the Galaxy instance
(for example |
include_deleted |
Logical; whether to include deleted datasets when summing (default FALSE) |
data.frame with columns history_id, bytes, human_size
histories <- galaxy_list_histories()
if(nrow(histories > 0)){
galaxy_history_size(histories$history_id[1])
} else {
message("No histories found for current user.")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.