| galaxy_initialize | R Documentation |
galaxy_initialize() is an S4 generic. With no x supplied it creates a
new history on the given Galaxy instance and returns its encoded ID. When
called with a Galaxy object it uses the object’s history_name and
galaxy_url, creates the history, and updates the object with the new
history_id and state "pending".
galaxy_initialize(
x,
name = "R API request",
galaxy_url = "https://usegalaxy.eu"
)
## S4 method for signature 'missing'
galaxy_initialize(name, galaxy_url)
## S4 method for signature 'Galaxy'
galaxy_initialize(x)
x |
A |
name |
Name of the history to create. Ignored when |
galaxy_url |
Base URL of the Galaxy instance. Ignored when |
A valid Galaxy API key is required and must be available via the
GALAXY_API_KEY environment variable.
For the default method (x missing), a character scalar history ID.
For the Galaxy method, the modified Galaxy object.
history_id <- galaxy_initialize("My history name")
g <- galaxy(history_name = "My history name")
g <- galaxy_initialize(g)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.