View source: R/2025-10-27_JF_R_Galaxy_functions.R
| galaxy_list_workflows | R Documentation |
Retrieves workflows accessible to the authenticated user from a Galaxy instance. Optionally includes public (published) workflows if supported by the Galaxy server.
galaxy_list_workflows(
include_public = FALSE,
galaxy_url = "https://usegalaxy.eu"
)
include_public |
Logical. If |
galaxy_url |
Character. Base URL of the Galaxy instance
(for example |
By default, only workflows owned by or shared with the current user
are returned. When include_public = TRUE, the function will
attempt to request published workflows as well. Availability of
public workflows depends on the Galaxy instance and version.
A data.frame with one row per workflow and columns including:
id, name, published, owner.
workflows <- galaxy_list_workflows(TRUE)
head(workflows)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.