| galaxy_poll_tool | R Documentation |
Generic for galaxy_poll_tool
Wait for a Galaxy job to complete
S4 method to poll the status of a tool invocation
galaxy_poll_tool(
x,
galaxy_url = "https://usegalaxy.eu",
poll_interval = 3,
timeout = 600
)
## S4 method for signature 'character'
galaxy_poll_tool(
x,
galaxy_url = "https://usegalaxy.eu",
poll_interval = 3,
timeout = 600
)
## S4 method for signature 'Galaxy'
galaxy_poll_tool(x, poll_interval = 3, timeout = 600)
x |
A job ID ( |
galaxy_url |
Base URL of the Galaxy instance, used by the character method. |
poll_interval |
Seconds between status checks. |
timeout |
Maximum time to wait in seconds. |
For the character method, the final job object; for the Galaxy
method, the modified Galaxy object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.