| galaxy_poll_workflow | R Documentation |
galaxy_poll_workflow() is an S4 generic. With x as a character vector it
is treated as a workflow invocation ID; the invocation is polled until it
completes and a list of output dataset IDs is returned. With x as a
Galaxy object, the invocation_id and galaxy_url are taken from the
object, and the object is updated with the resulting output_dataset_ids and
state.
galaxy_poll_workflow(
x,
galaxy_url = "https://usegalaxy.eu",
poll_interval = 30,
...
)
## S4 method for signature 'character'
galaxy_poll_workflow(
x,
galaxy_url = "https://usegalaxy.eu",
poll_interval = 30,
...
)
## S4 method for signature 'Galaxy'
galaxy_poll_workflow(
x,
galaxy_url = "https://usegalaxy.eu",
poll_interval = 30,
...
)
x |
A workflow invocation ID ( |
galaxy_url |
Base URL of the Galaxy instance, used by the character
method. If |
poll_interval |
Time in seconds between polling attempts. |
... |
not in use |
For the character method, a list with elements success and
output_ids. For the Galaxy method, the modified Galaxy object.
invocation_id <- "abc123"
galaxy_poll_workflow(invocation_id)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.