| galaxy_run_tool | R Documentation |
galaxy_run_tool() is an S4 generic. With x as a character vector it is
treated as a history ID; the specified tool is invoked in that history and
the job ID is returned. With x as a Galaxy object, the history ID and
URL are taken from the object and the object is updated with the job ID.
galaxy_run_tool(
x,
tool_id,
inputs = NULL,
dataset_id = NULL,
galaxy_url = "https://usegalaxy.eu"
)
## S4 method for signature 'character'
galaxy_run_tool(
x,
tool_id,
inputs = NULL,
dataset_id = NULL,
galaxy_url = "https://usegalaxy.eu"
)
## S4 method for signature 'Galaxy'
galaxy_run_tool(x, tool_id, inputs = NULL, dataset_id = NULL)
x |
A history ID ( |
tool_id |
Tool identifier to execute. |
inputs |
Named list of tool inputs. |
dataset_id |
ID of the input dataset (HDA). |
galaxy_url |
Base URL of the Galaxy instance, used by the character method. |
For the character method, a job ID; for the Galaxy method, the
modified Galaxy object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.