| galaxy_start_workflow | R Documentation |
galaxy_start_workflow() is an S4 generic. With x as a character vector
it is treated as a history ID: the given workflow is invoked in that history
and the invocation ID is returned. With x as a Galaxy object, the
history ID and URL are taken from the object; the workflow is started and
the object is updated with the resulting invocation_id.
galaxy_start_workflow(
x,
workflow_id,
inputs = NULL,
dataset_id = NULL,
galaxy_url = "https://usegalaxy.eu"
)
## S4 method for signature 'character'
galaxy_start_workflow(
x,
workflow_id,
inputs = NULL,
dataset_id = NULL,
galaxy_url = "https://usegalaxy.eu"
)
## S4 method for signature 'Galaxy'
galaxy_start_workflow(x, workflow_id, inputs = NULL, dataset_id = NULL)
x |
A |
workflow_id |
Character. Galaxy workflow ID. |
inputs |
Named list. Optional workflow input mapping; keys are workflow input step IDs, values are lists describing datasets/parameters. |
dataset_id |
Character. ID of the input dataset (HDA). Ignored if
|
galaxy_url |
Base URL of the Galaxy instance, used by the character
method. If |
For the character method, a character scalar invocation ID. For the
Galaxy method, the modified Galaxy object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.