| galaxy_upload_ftp | R Documentation |
galaxy_upload_ftp() is an S4 generic. With no x supplied it uploads a
local file via FTP and registers it in the specified history, returning the
encoded dataset ID. When called with a Galaxy object it uses the
object's history_id and galaxy_url and updates the object with the new
input_dataset_id.
galaxy_upload_ftp(
x,
input_file,
galaxy_ftp = "ftp.usegalaxy.eu",
galaxy_url = "https://usegalaxy.eu",
...
)
## S4 method for signature 'character'
galaxy_upload_ftp(
x,
input_file,
galaxy_ftp = "ftp.usegalaxy.eu",
galaxy_url = "https://usegalaxy.eu",
...
)
## S4 method for signature 'Galaxy'
galaxy_upload_ftp(
x,
input_file,
galaxy_ftp = "ftp.usegalaxy.eu",
galaxy_url = "https://usegalaxy.eu",
...
)
x |
A |
input_file |
Path to the local file to upload. |
galaxy_ftp |
FTP server address of the Galaxy instance. |
galaxy_url |
Base URL of the Galaxy instance, used by the default
method. If |
... |
not in use |
A valid API key (GALAXY_API_KEY) and FTP credentials (GALAXY_USERNAME,
GALAXY_PASSWORD) must be available in the environment.
For the default method, a character scalar dataset ID. For the
Galaxy method, the modified Galaxy object.
galaxy_ftp <- "ftp.usegalaxy.eu"
input_file <- tempfile(fileext = ".txt")
writeLines("Example", input_file)
hid <- galaxy_initialize("test upload")
did <- galaxy_upload_ftp(input_file, hid, galaxy_ftp)
g <- galaxy()
g <- galaxy_initialize(g)
g <- galaxy_upload_ftp(g, input_file, galaxy_ftp = galaxy_ftp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.